==> totoui-0.3.0.tgz: package/lib/tabs.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _minxinsClassNameMixin = require('./minxins/ClassNameMixin');

var _minxinsClassNameMixin2 = _interopRequireDefault(_minxinsClassNameMixin);

var _objectOmit = require('object.omit');

var _objectOmit2 = _interopRequireDefault(_objectOmit);

var _navJsx = require('./nav.js');

var _navJsx2 = _interopRequireDefault(_navJsx);

var _navItemJsx = require('./navItem.js');

var _navItemJsx2 = _interopRequireDefault(_navItemJsx);

var _tabsItemJsx = require('./tabsItem.js');

var _tabsItemJsx2 = _interopRequireDefault(_tabsItemJsx);

var Tabs = (function (_React$Component) {
    _inherits(Tabs, _React$Component);

    function Tabs(props) {
        _classCallCheck(this, Tabs);

        _get(Object.getPrototypeOf(Tabs.prototype), 'constructor', this).call(this, props);
        for (var v in _minxinsClassNameMixin2['default']) {
            this[v] = _minxinsClassNameMixin2['default'][v].bind(this);
        }
        var defaultActiveKey = this.props.defaultActiveKey != null ? this.props.defaultActiveKey : this.getDefaultActiveKey(this.props.children);
        this.state = {
            activeKey: defaultActiveKey,
            previousActiveKey: null
        };
        this.componentWillReceiveProps = this.componentWillReceiveProps.bind(this);
        this.getDefaultActiveKey = this.getDefaultActiveKey.bind(this);
        this.handleClick = this.handleClick.bind(this);
        this.renderNav = this.renderNav.bind(this);
        this.renderTabPanels = this.renderTabPanels.bind(this);
        this.renderData = this.renderData.bind(this);
        this.renderWrapper = this.renderWrapper.bind(this);
        this.renderNavWrapper = this.renderNavWrapper.bind(this);
        this.renderBodyWrapper = this.renderBodyWrapper.bind(this);
    }

    _createClass(Tabs, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
            if (nextProps.activeKey != null && nextProps.activeKey !== this.props.activeKey) {
                this.setState({
                    previousActiveKey: this.props.activeKey
                });
            }
        }
    }, {
        key: 'getDefaultActiveKey',
        value: function getDefaultActiveKey(children) {
            var defaultActiveKey = null;

            if (this.props.data) {
                this.props.data.every(function (item, i) {
                    if (item.active) {
                        defaultActiveKey = i;
                        return false;
                    }

                    return true;
                });

                return defaultActiveKey == null ? 0 : defaultActiveKey;
            }

            _react2['default'].Children.forEach(children, function (child) {
                if (defaultActiveKey == null) {
                    defaultActiveKey = child.props.eventKey;
                }
            });

            return defaultActiveKey;
        }
    }, {
        key: 'handleClick',
        value: function handleClick(key, disabled, e) {
            e.preventDefault();
            var activeKey = this.state.activeKey;

            if (disabled) {
                return null;
            }

            if (this.props.onSelect) {
                this.props.onSelect(key);
            }

            if (activeKey !== key) {
                this.setState({
                    activeKey: key,
                    previousActiveKey: activeKey
                });
            }
        }
    }, {
        key: 'renderNav',
        value: function renderNav() {
            var activeKey = this.state.activeKey;

            return _react2['default'].Children.map(this.props.children, (function (child, index) {
                var key = child.props.key || child.props.eventKey || index;
                var disabled = child.props.disabled;

                return _react2['default'].createElement(
                    _navItemJsx2['default'],
                    {
                        href: "#",
                        ref: 'ref' + key,
                        key: key,
                        onClick: this.handleClick.bind(this, key, disabled),
                        active: child.props.eventKey === activeKey,
                        disabled: disabled },
                    child.props.title
                );
            }).bind(this));
        }
    }, {
        key: 'renderTabPanels',
        value: function renderTabPanels() {
            var activeKey = this.state.activeKey;

            return _react2['default'].Children.map(this.props.children, function (child, index) {
                return _react2['default'].createElement(
                    _tabsItemJsx2['default'],
                    {
                        active: child.props.eventKey === activeKey,
                        key: child.props.key ? child.props.key : index },
                    child.props.children
                );
            });
        }

        // for Amaze UI tabs widget
    }, {
        key: 'renderData',
        value: function renderData() {
            var activeKey = this.state.activeKey;
            var navs = [];
            var panels = [];

            this.props.data.forEach((function (item, key) {
                navs.push(_react2['default'].createElement(
                    _navItemJsx2['default'],
                    {
                        href: "#",
                        ref: 'ref' + key,
                        key: key,
                        onClick: this.handleClick.bind(this, key, item.disabled),
                        active: key === activeKey,
                        disabled: item.disabled },
                    item.title
                ));

                panels.push(_react2['default'].createElement(
                    _tabsItemJsx2['default'],
                    {
                        eventKey: key,
                        // active={item.active}
                        active: key === activeKey,
                        key: key },
                    item.content
                ));
            }).bind(this));

            return {
                navs: navs,
                panels: panels
            };
        }
    }, {
        key: 'renderWrapper',
        value: function renderWrapper(children) {
            var classSet = this.getClassSet();
            var props = (0, _objectOmit2['default'])(this.props, 'data');

            return _react2['default'].createElement(
                'div',
                _extends({}, props, {
                    'data-ui-widget': this.props.theme ? this.props.classPrefix : null,
                    className: (0, _classnames2['default'])(classSet, this.props.className) }),
                children
            );
        }
    }, {
        key: 'renderNavWrapper',
        value: function renderNavWrapper(children) {
            var TabsNav = this.props.theme ? 'ul' : _navJsx2['default'];

            return _react2['default'].createElement(
                TabsNav,
                {
                    key: "tabsNav",
                    tabs: true,
                    className: (0, _classnames2['default'])(this.prefixClass('nav'), this.setClassNamespace('cf')),
                    justify: this.props.justify },
                children
            );
        }
    }, {
        key: 'renderBodyWrapper',
        value: function renderBodyWrapper(children) {
            var animationClass = this.prefixClass(this.props.animation);

            return _react2['default'].createElement(
                'div',
                {
                    key: "tabsBody",
                    className: (0, _classnames2['default'])(this.prefixClass('bd'), animationClass) },
                children
            );
        }
    }, {
        key: 'render',
        value: function render() {
            var children = this.props.data ? this.renderData() : {};

            return this.renderWrapper([this.renderNavWrapper(children.navs || this.renderNav()), this.renderBodyWrapper(children.panels || this.renderTabPanels())]);
        }
    }]);

    return Tabs;
})(_react2['default'].Component);

Tabs.displayName = "Tabs";

Tabs.propTypes = {
    theme: _react2['default'].PropTypes.oneOf(['default', 'd2']),
    onSelect: _react2['default'].PropTypes.func,
    animation: _react2['default'].PropTypes.oneOf(['slide', 'fade']),
    defaultActiveKey: _react2['default'].PropTypes.any,
    justify: _react2['default'].PropTypes.bool,
    data: _react2['default'].PropTypes.array
};

Tabs.defaultProps = {
    classPrefix: 'tabs',
    animation: 'fade'
};

module.exports = Tabs;

==> totoui-0.5.1.tgz: package/lib/tabs.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _mixinsClassNameMixin = require('./mixins/ClassNameMixin');

var _mixinsClassNameMixin2 = _interopRequireDefault(_mixinsClassNameMixin);

var _objectOmit = require('object.omit');

var _objectOmit2 = _interopRequireDefault(_objectOmit);

var _navJsx = require('./nav.js');

var _navJsx2 = _interopRequireDefault(_navJsx);

var _navItemJsx = require('./navItem.js');

var _navItemJsx2 = _interopRequireDefault(_navItemJsx);

var _tabsItemJsx = require('./tabsItem.js');

var _tabsItemJsx2 = _interopRequireDefault(_tabsItemJsx);

var Tabs = (function (_React$Component) {
    _inherits(Tabs, _React$Component);

    function Tabs(props) {
        _classCallCheck(this, Tabs);

        _get(Object.getPrototypeOf(Tabs.prototype), 'constructor', this).call(this, props);
        for (var v in _mixinsClassNameMixin2['default']) {
            this[v] = _mixinsClassNameMixin2['default'][v].bind(this);
        }
        var defaultActiveKey = this.props.defaultActiveKey != null ? this.props.defaultActiveKey : this.getDefaultActiveKey(this.props.children);
        this.state = {
            activeKey: defaultActiveKey,
            previousActiveKey: null
        };
        this.componentWillReceiveProps = this.componentWillReceiveProps.bind(this);
        this.getDefaultActiveKey = this.getDefaultActiveKey.bind(this);
        this.handleClick = this.handleClick.bind(this);
        this.renderNav = this.renderNav.bind(this);
        this.renderTabPanels = this.renderTabPanels.bind(this);
        this.renderData = this.renderData.bind(this);
        this.renderWrapper = this.renderWrapper.bind(this);
        this.renderNavWrapper = this.renderNavWrapper.bind(this);
        this.renderBodyWrapper = this.renderBodyWrapper.bind(this);
    }

    _createClass(Tabs, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
            if (nextProps.activeKey != null && nextProps.activeKey !== this.props.activeKey) {
                this.setState({
                    previousActiveKey: this.props.activeKey
                });
            }
        }
    }, {
        key: 'getDefaultActiveKey',
        value: function getDefaultActiveKey(children) {
            var defaultActiveKey = null;

            if (this.props.data) {
                this.props.data.every(function (item, i) {
                    if (item.active) {
                        defaultActiveKey = i;
                        return false;
                    }

                    return true;
                });

                return defaultActiveKey == null ? 0 : defaultActiveKey;
            }

            _react2['default'].Children.forEach(children, function (child) {
                if (defaultActiveKey == null) {
                    defaultActiveKey = child.props.eventKey;
                }
            });

            return defaultActiveKey;
        }
    }, {
        key: 'handleClick',
        value: function handleClick(key, disabled, e) {
            e.preventDefault();
            var activeKey = this.state.activeKey;

            if (disabled) {
                return null;
            }

            if (this.props.onSelect) {
                this.props.onSelect(key);
            }

            if (activeKey !== key) {
                this.setState({
                    activeKey: key,
                    previousActiveKey: activeKey
                });
            }
        }
    }, {
        key: 'renderNav',
        value: function renderNav() {
            var activeKey = this.state.activeKey;

            return _react2['default'].Children.map(this.props.children, (function (child, index) {
                var key = child.props.key || child.props.eventKey || index;
                var disabled = child.props.disabled;

                return _react2['default'].createElement(
                    _navItemJsx2['default'],
                    {
                        href: '#',
                        ref: 'ref' + key,
                        key: key,
                        onClick: this.handleClick.bind(this, key, disabled),
                        active: child.props.eventKey === activeKey,
                        disabled: disabled },
                    child.props.title
                );
            }).bind(this));
        }
    }, {
        key: 'renderTabPanels',
        value: function renderTabPanels() {
            var activeKey = this.state.activeKey;

            return _react2['default'].Children.map(this.props.children, function (child, index) {
                return _react2['default'].createElement(
                    _tabsItemJsx2['default'],
                    {
                        active: child.props.eventKey === activeKey,
                        key: child.props.key ? child.props.key : index },
                    child.props.children
                );
            });
        }

        // for Amaze UI tabs widget
    }, {
        key: 'renderData',
        value: function renderData() {
            var activeKey = this.state.activeKey;
            var navs = [];
            var panels = [];

            this.props.data.forEach((function (item, key) {
                navs.push(_react2['default'].createElement(
                    _navItemJsx2['default'],
                    {
                        href: '#',
                        ref: 'ref' + key,
                        key: key,
                        onClick: this.handleClick.bind(this, key, item.disabled),
                        active: key === activeKey,
                        disabled: item.disabled },
                    item.title
                ));

                panels.push(_react2['default'].createElement(
                    _tabsItemJsx2['default'],
                    {
                        eventKey: key,
                        // active={item.active}
                        active: key === activeKey,
                        key: key },
                    item.content
                ));
            }).bind(this));

            return {
                navs: navs,
                panels: panels
            };
        }
    }, {
        key: 'renderWrapper',
        value: function renderWrapper(children) {
            var classSet = this.getClassSet();
            var props = (0, _objectOmit2['default'])(this.props, 'data');

            return _react2['default'].createElement(
                'div',
                _extends({}, props, {
                    'data-widget': this.props.theme ? this.props.classPrefix : null,
                    className: (0, _classnames2['default'])(classSet, this.props.className) }),
                children
            );
        }
    }, {
        key: 'renderNavWrapper',
        value: function renderNavWrapper(children) {
            var TabsNav = this.props.theme ? 'ul' : _navJsx2['default'];

            return _react2['default'].createElement(
                TabsNav,
                {
                    key: 'tabsNav',
                    tabs: true,
                    className: (0, _classnames2['default'])(this.prefixClass('nav'), this.setClassNamespace('cf')),
                    justify: this.props.justify },
                children
            );
        }
    }, {
        key: 'renderBodyWrapper',
        value: function renderBodyWrapper(children) {
            var animationClass = this.prefixClass(this.props.animation);

            return _react2['default'].createElement(
                'div',
                {
                    key: 'tabsBody',
                    className: (0, _classnames2['default'])(this.prefixClass('bd'), animationClass) },
                children
            );
        }
    }, {
        key: 'render',
        value: function render() {
            var children = this.props.data ? this.renderData() : {};

            return this.renderWrapper([this.renderNavWrapper(children.navs || this.renderNav()), this.renderBodyWrapper(children.panels || this.renderTabPanels())]);
        }
    }]);

    return Tabs;
})(_react2['default'].Component);

Tabs.displayName = "Tabs";

Tabs.propTypes = {
    theme: _react2['default'].PropTypes.oneOf(['default', 'd2']),
    onSelect: _react2['default'].PropTypes.func,
    animation: _react2['default'].PropTypes.oneOf(['slide', 'fade']),
    defaultActiveKey: _react2['default'].PropTypes.any,
    justify: _react2['default'].PropTypes.bool,
    data: _react2['default'].PropTypes.array
};

Tabs.defaultProps = {
    classPrefix: 'tabs',
    animation: 'fade'
};

module.exports = Tabs;
